" Plugins //////////////////////////////////////////////////////////////////////////////////////////
call plug#begin(stdpath('config') . '/plugged')
    " nerdtree provides a file tree explorer
    " vim-dispatch allows running async jobs in vim (i.e. builds in the background)
    Plug 'https://github.com/scrooloose/nerdtree', { 'on': 'NERDTreeToggle' }
    Plug 'https://github.com/tpope/vim-dispatch'
    Plug 'https://github.com/tpope/vim-fugitive'
    Plug 'https://github.com/tpope/vim-abolish'
    Plug 'https://github.com/LunarVim/bigfile.nvim'

    " FZF
    Plug 'junegunn/fzf'
    Plug 'ibhagwan/fzf-lua', {'branch': 'main'}
    Plug 'nvim-tree/nvim-web-devicons'

    " Other ////////////////////////////////////////////////////////////////////////////////////////
    " TODO: 2022-06-19 Treesitter is too slow on large C++ files
    " Plug 'https://github.com/nvim-treesitter/nvim-treesitter', {'do': ':TSUpdate'}
    Plug 'junegunn/vim-easy-align'
    Plug 'https://github.com/bfrg/vim-cpp-modern'
    Plug 'https://github.com/ggandor/leap.nvim'
    Plug 'https://github.com/sainnhe/gruvbox-material'
    Plug 'https://github.com/Tetralux/odin.vim' "Odin Syntax highlighting

    " Harpoon //////////////////////////////////////////////////////////////////////////////////////
    Plug 'nvim-lua/plenary.nvim'

    " lsp-zero begin
        " LSP Support
        Plug 'williamboman/mason.nvim'
        Plug 'williamboman/mason-lspconfig.nvim'
        Plug 'neovim/nvim-lspconfig'
        Plug 'hrsh7th/nvim-cmp'
        Plug 'hrsh7th/cmp-nvim-lsp'
        Plug 'L3MON4D3/LuaSnip'
        Plug 'hrsh7th/cmp-buffer'
        Plug 'hrsh7th/cmp-path'
        Plug 'VonHeikemen/lsp-zero.nvim', {'branch': 'v3.x'}

        Plug 'huggingface/llm.nvim'
    " lsp-zero end
call plug#end()

" Lua Setup ////////////////////////////////////////////////////////////////////////////////////////
lua <<EOF
  local leap = require('leap')
  vim.keymap.set({'n', 'x', 'o'}, '<tab>', '<Plug>(leap)')
  vim.keymap.set({'n', 'x', 'o'}, '<S-tab>', '<Plug>(leap-from-window)')

  require('bigfile').setup()
  require('fzf-lua').setup{
    winopts = {
       height=0.95,
       width=0.95
    }
  }

  -- Vim Dispatch //////////////////////////////////////////////////////////////////////////////////
  if vim.fn.has('win64') or vim.fn.has('win32') or vim.fn.has('win16') then
    if os.getenv('SHELL') ~= nil then
      vim.o.shellcmdflag = '-c'
      vim.o.makeprg      = "./build.sh"
    else
      vim.o.makeprg      = "build.bat"
    end
  else
    -- vim.api.nvim_set_keymap('t', '<Esc>', '<C-\\><C-n>', {noremap = true})
    vim.o.makeprg        = "./build.sh"
  end
  vim.api.nvim_set_keymap('n', '<C-b>', ':Make<CR>', {noremap = true})

  -- LSP Setup /////////////////////////////////////////////////////////////////////////////////////
  local lsp_zero = require('lsp-zero')
  lsp_zero.on_attach(function(client, bufnr)
    -- see :help lsp-zero-keybindings
    -- to learn the available actions
    lsp_zero.default_keymaps({
        buffer = bufnr,
        exclude = {'<F3>'}, -- Disable code-format of current buffer
    })
    local opts = {buffer = bufnr}

    vim.keymap.set({'v', 'x'}, 'gq', function()
      vim.lsp.buf.format({async = false, timeout_ms = 10000})
    end, opts)
  end)

  -- to learn how to use mason.nvim with lsp-zero
  -- read this: https://github.com/VonHeikemen/lsp-zero.nvim/blob/v3.x/doc/md/guide/integrate-with-mason-nvim.md
  require('mason').setup({})
  require('mason-lspconfig').setup({
    ensure_installed = { "clangd" },
    handlers = {
      lsp_zero.default_setup,
    },
  })

  local cmp = require('cmp')
  local cmp_action = require('lsp-zero').cmp_action()
  local cmp_format = require('lsp-zero').cmp_format({details = true})

  cmp.setup({
    sources = {
      {name = 'nvim_lsp'},
      {name = 'buffer'},
      {name = 'path'},

    },
    mapping = cmp.mapping.preset.insert({
      ['<Tab>'] = cmp_action.luasnip_supertab(),
      ['<S-Tab>'] = cmp_action.luasnip_shift_supertab(),
      ['<CR>'] = cmp.mapping.confirm({select = false}),
    }),
    snippet = {
      expand = function(args)
        require('luasnip').lsp_expand(args.body)
      end,
    },
    --- (Optional) Show source name in completion menu
    formatting = cmp_format,
  })

  -- LLM ///////////////////////////////////////////////////////////////////////////////////////////
  -- local llm = require('llm')
  -- llm.setup({
  --   api_token       = nil,                                         -- cf Install paragraph
  --   model           = "codellama/CodeLlama-13b-hf",                -- the model ID, behavior depends on backend
  --   backend         = "openai",                                    -- backend ID, "huggingface" | "ollama" | "openai" | "tgi"
  --   url             = "http://localhost:8080/v1/chat/completions", -- the http url of the backend
  --   tokens_to_clear = { "<EOT>" },                                 -- tokens to remove from the model's output
  --   -- parameters that are added to the request body, values are arbitrary, you can set any field:value pair here it will be passed as is to the backend
  --   request_body = { },
  --   -- set this if the model supports fill in the middle
  --   fim = {
  --     enabled = true,
  --     prefix  = "<PRE> ",
  --     middle  = " <MID>",
  --     suffix  = " <SUF>",
  --   },
  --   debounce_ms              = 150,
  --   accept_keymap            = "<S-CR>",
  --   dismiss_keymap           = "<CR>",
  --   tls_skip_verify_insecure = false,
  --   -- llm-ls configuration, cf llm-ls section
  --   lsp = {
  --     bin_path = "C:/Home/Downloads/llm-ls.exe",
  --     host     = nil,
  --     port     = nil,
  --   },
  --   tokenizer                     = {
  --     path = "C:/Home/Models/codellama-7b_tokenizer.json",
  --   },  -- cf Tokenizer paragraph
  --   context_window                = 4096, -- max number of tokens for the context window
  --   enable_suggestions_on_startup = true,
  --   enable_suggestions_on_files   = "*",  -- pattern matching syntax to enable suggestions on specific files, either a string or a list of strings
  -- })

  -- Treesitter ////////////////////////////////////////////////////////////////////////////////////
  -- TODO: 2022-06-19 Treesitter is too slow on large C++ files
  -- require('nvim-treesitter.configs').setup {
  --   ensure_installed = { "c", "cpp" }, -- A list of parser names, or "all"
  --   sync_install     = false,          -- Install parsers synchronously (only applied to `ensure_installed`)
  --   ignore_install   = { },            -- List of parsers to ignore installing (for "all")

  --   highlight = {
  --     enable = false, -- `false` will disable the whole extension

  --     -- NOTE: these are the names of the parsers and not the filetype. (for example if you want to
  --     -- disable highlighting for the `tex` filetype, you need to include `latex` in this list as this is
  --     -- the name of the parser)
  --     -- list of language that will be disabled
  --     disable = { },

  --     -- Setting this to true will run `:h syntax` and tree-sitter at the same time.
  --     -- Set this to `true` if you depend on 'syntax' being enabled (like for indentation).
  --     -- Using this option may slow down your editor, and you may see some duplicate highlights.
  --     -- Instead of true it can also be a list of languages
  --     additional_vim_regex_highlighting = false,
  --   },
  -- }


  -- Per-Project Bindings /////////////////////////////////////////////////////////////////////////////
  -- Automatically load project file on buffer enter
  vim.api.nvim_create_autocmd({"BufEnter"}, {
    callback = function(ev)
      local project_file = vim.fn.expand('%:p:h') .. '/project_nvim.lua'
      if vim.fn.filereadable(project_file) == 1 then
          vim.cmd('luafile ' .. vim.fn.fnameescape(project_file))
      end
    end
  })

  -- Vim Options ///////////////////////////////////////////////////////////////////////////////////
  vim.opt.autowrite=true        -- Automatically save before cmds like :next and :prev
  vim.opt.colorcolumn={80, 100} -- Set a 80 and 100 char column ruler
  vim.opt.completeopt={'menu', 'menuone', 'noselect'}
  vim.opt.cpoptions:append('$') -- $ as end marker for the change operator
  vim.opt.cursorline=true       -- Highlight current line
  vim.opt.expandtab=true        -- Replace tabs with spaces
  vim.opt.guifont='JetBrains_Mono:h9','Consolas:h9','InputMonoCondensed:h9'
  vim.opt.hlsearch=false        -- Highlight just the first match on search
  vim.opt.ignorecase=true       -- Search is not case sensitive
  vim.opt.linebreak=true        -- On wrapped lines, break on the wrapping word intelligently
  vim.opt.list=true             -- Show the 'listchar' characters on trailing spaces, tabs e.t.c ===
  vim.opt.listchars:append('tab:>-,trail:■,extends:»,precedes:«')
  vim.opt.number=true           -- Show line numbers
  vim.opt.relativenumber=true   -- Show relative line numbers
  vim.opt.shiftwidth=4          -- Number of spaces for each autoindent step
  vim.opt.splitright=true       -- Open new splits to the right of the current one
  vim.opt.swapfile=false        -- Disable swapfile (stores the things changed in a file)
  vim.opt.textwidth=80          -- On format, format to 80 char long lines
  vim.opt.visualbell=true       -- Flash the screen on error
  vim.opt.wrap=false            -- Don't wrap lines of text automatically
  vim.opt.signcolumn = 'no'

  vim.diagnostic.config({
    -- Turn off the diagnostics signs on the line number. In LSP mode, editing
    -- a C++ buffer constantly toggles the sign column on and off as you change
    -- modes which is very visually distracting.
    signs = false,
  })

  -- Automatically scroll to bottom of quickfix window when opened
  vim.cmd([[
    autocmd FileType qf lua vim.cmd('normal! G')
  ]])
EOF

" Theme ////////////////////////////////////////////////////////////////////////////////////////////
let g:gruvbox_material_background='hard'
let g:gruvbox_material_foreground='mix'
let g:gruvbox_material_disable_italic_comment=1
let g:gruvbox_material_enable_italic=0
let g:gruvbox_material_enable_bold=0
let g:gruvbox_material_diagnostic_virtual_text='colored'
let g:gruvbox_material_better_performance=1
colorscheme gruvbox-material

" Vim-cpp-modern customisation
" Disable function highlighting (affects both C and C++ files)
let g:cpp_function_highlight = 1

" Enable highlighting of C++11 attributes
let g:cpp_attributes_highlight = 1

" Highlight struct/class member variables (affects both C and C++ files)
let g:cpp_member_highlight = 0

" Put all standard C and C++ keywords under Vim's highlight group 'Statement'
" (affects both C and C++ files)
let g:cpp_simple_highlight = 1

" Options //////////////////////////////////////////////////////////////////////////////////////////
" Show EOL type and last modified timestamp, right after the filename
set statusline=%<%F%h%m%r\ [%{&ff}]\ (%{strftime(\"%H:%M\ %d/%m/%Y\",getftime(expand(\"%:p\")))})%=%l,%c%V\ %P

" File patterns to ignore in command line auto complete
set wildignore+=*.class,*.o,*\\tmp\\*,*.swp,*.zip,*.exe,*.obj,*.vcxproj,*.pdb,*.idb

" Setup undo file
set undofile
let &undodir=stdpath('config') . '/undo'

" Setup backup directory
let &backupdir=stdpath('config') . '/backup'

" Enable mouse support
if has('mouse')
    set mouse=a
endif

" Functions ////////////////////////////////////////////////////////////////////////////////////////
" Increase font size using (Ctrl+Up Arrow) or (Ctrl+Down Arrow) if we are using
" gvim Otherwise font size is determined in terminal
nnoremap <C-Up> :silent! let &guifont = substitute(
 \ &guifont,
 \ ':h\zs\d\+',
 \ '\=eval(submatch(0)+1)',
 \ 'g')<CR>
nnoremap <C-Down> :silent! let &guifont = substitute(
 \ &guifont,
 \ ':h\zs\d\+',
 \ '\=eval(submatch(0)-1)',
 \ 'g')<CR>

" Formatting options (see :h fo-table)
augroup persistent_settings
  au!
  au bufenter * :set formatoptions=q1j
augroup end

function! RADDbgOpenFile()
    execute("!dev raddbg --ipc open " . substitute(expand("%:p"), '\\', '/', 'g'))
    execute("!dev raddbg --ipc goto_line " . line("."))
    execute("!powershell -Command Add-Type -AssemblyName Microsoft.VisualBasic; [Microsoft.VisualBasic.Interaction]::AppActivate('The RAD Debugger')")
endfunction
command RADDbgOpenFile call RADDbgOpenFile()

function! RADDbgStartDebugging()
    execute("!dev raddbg --ipc run")
endfunction
command RADDbgStartDebugging call RADDbgStartDebugging()

function! RADDbgStopDebugging()
    execute("!dev raddbg --ipc kill_all")
endfunction
command RADDbgStopDebugging call RADDbgStopDebugging()

function! RADDbgRunToCursor()
    execute("!dev raddbg --ipc open "          . substitute(expand("%:p"), '\\', '/', 'g'))
    execute("!dev raddbg --ipc goto_line "     . line("."))
    execute("!dev raddbg --ipc run_to_cursor " . substitute(expand("%:p"), '\\', '/', 'g') . ":" . line("."))
    execute("!powershell -Command Add-Type -AssemblyName Microsoft.VisualBasic; [Microsoft.VisualBasic.Interaction]::AppActivate('The RAD Debugger')")
endfunction
command RADDbgRunToCursor call RADDbgRunToCursor()

function! RADDbgAddBreakpointAtFile()
    execute("!dev raddbg --ipc open "              . substitute(expand("%:p"), '\\', '/', 'g'))
    execute("!dev raddbg --ipc goto_line "         . line("."))
    execute("!dev raddbg --ipc toggle_breakpoint " . substitute(expand("%:p"), '\\', '/', 'g') . ":" . line("."))
    execute("!powershell -Command Add-Type -AssemblyName Microsoft.VisualBasic; [Microsoft.VisualBasic.Interaction]::AppActivate('The RAD Debugger')")
endfunction
command RADDbgAddBreakpointAtFile call RADDbgAddBreakpointAtFile()

nnoremap <silent> <F6>    <cmd>RADDbgOpenFile<cr><cr>
nnoremap <silent> <F5>    <cmd>RADDbgStartDebugging<cr><cr>
nnoremap <silent> <S-F5>  <cmd>RADDbgStopDebugging<cr><cr>
nnoremap <silent> <F9>    <cmd>RADDbgAddBreakpointAtFile<cr><cr>
nnoremap <silent> <C-F10> <cmd>RADDbgRunToCursor<cr><cr>

" General Key Bindings /////////////////////////////////////////////////////////////////////////////
" FZF Bindings
nnoremap <leader>h  <cmd>FzfLua oldfiles<cr>
nnoremap <leader>f  <cmd>FzfLua files<cr>
nnoremap <leader>r  <cmd>FzfLua live_grep<cr>
nnoremap <leader>R  <cmd>FzfLua grep_cword<cr>
nnoremap <leader>t  <cmd>FzfLua lsp_live_workspace_symbols<cr>
nnoremap <leader>T  <cmd>FzfLua lsp_finder<cr>
nnoremap <leader>b  <cmd>FzfLua buffers<cr>
nnoremap <leader><leader> <cmd>FzfLua<cr>

" Map Ctrl+HJKL to navigate buffer window
nmap <silent> <C-h> :wincmd h<CR>
nmap <silent> <C-j> :wincmd j<CR>
nmap <silent> <C-k> :wincmd k<CR>
nmap <silent> <C-l> :wincmd l<CR>

" Move by wrapped lines instead of line numbers
nnoremap j gj
nnoremap k gk
nnoremap gj j
nnoremap gk k

" Map NERDTree to Ctrl-N
map <C-n> :NERDTreeToggle<CR>

" Change to current buffer's directory
nmap cd :cd <C-R>=expand("%:p:h")<CR><CR>

" Buffer Splitting
nnoremap <leader>s :vs<CR>

" Go to next error
" Go to previous error
nnoremap <A-j> :cn<CR>
nnoremap <A-k> :cp<CR>

" In Neovim terminal, pressing <ESC> should go back into normal mode.
" Without this, this doesn't happen and you stay stuck in insert mode.
tnoremap <Esc> <C-\><C-n>

" Easy-Align ///////////////////////////////////////////////////////////////////////////////////////
let g:easy_align_delimiters = {
\ '>': { 'pattern': '>>\|=>\|>' },
\ '/': {
\     'pattern':         '//\+\|/\*\|\*/',
\     'delimiter_align': 'l',
\     'ignore_groups':   ['!Comment'] },
\ ']': {
\     'pattern':       '[[\]]',
\     'left_margin':   0,
\     'right_margin':  0,
\     'stick_to_left': 0
\   },
\ ')': {
\     'pattern':       '[)]',
\     'left_margin':   0,
\     'right_margin':  0,
\     'stick_to_left': 0
\   },
\ '(': {
\     'pattern':       '[(]',
\     'left_margin':   0,
\     'right_margin':  0,
\     'stick_to_left': 0
\   },
\ }

" Enter live-interactive easy align mode when a visual selection is active
xmap <leader>a <Plug>(LiveEasyAlign)
